@@ -1,7 +1,7 @@
 subroutine bfun(fy,xispd,tpm,epsilon,n,nstate,wrk,beta)
 implicit double precision(a-h,o-z)
-dimension wrk(1), xispd(1)
-dimension fy(nstate,1), tpm(nstate,1), beta(nstate,1)
+dimension wrk(nstate), xispd(nstate)
+dimension fy(nstate,n), tpm(nstate,nstate), beta(nstate,n)
 
 # Set some constants.
 one  = 1.d0
